Functions to compute Mills ratios for different probability distributions. The Mills ratio m(x) is defined as the ratio of the complementary cumulative distribution function (CCDF) to the probability density function (PDF): m(x) = \[1 - F(x)\] / f(x)
Author
John Gavin john.b.gavin@gmail.com Compute Mills Ratio for Normal Distribution
Examples
# Standard normal Mills ratio at x = 2
mills_ratio_normal(2)
#> [1] 0.4213692
# Multiple values
mills_ratio_normal(c(1, 2, 3, 4))
#> [1] 0.6556795 0.4213692 0.3045903 0.2366524
# Log Mills ratio for extreme values
mills_ratio_normal(10, log = TRUE)
#> [1] -2.312347